WebSocket library for native and WebAssembly targets.
Features
- Native (tokio-tungstenite) support on non-wasm targets
- Browser WebSocket support on wasm32 targets
Modules
- crypto
- Simple crypto provider utilities for rustls.
- stream
- Sink/Stream split helpers for Tokio Tungstenite connections.
- tls
- TLS configuration helpers for managing certificates and private keys.
Structs
- Bytes
- A cheaply cloneable and sliceable chunk of contiguous memory.
- Client
- Reusable WebSocket client created by
ClientBuilder. - Client
Builder - Builder for creating a WebSocket client.
- Close
Frame - Close frame metadata associated with WebSocket close events.
- Connect
Options - Connection configuration shared by native and WebAssembly transports.
- Connection
- WebSocket connection wrapper around a Tokio Tungstenite stream.
- Dangerous
Client Builder - Builder that can create clients with disabled certificate verification.
- Server
- WebSocket server listener.
- Server
Builder - Builder for creating a WebSocket server.
- Server
Options - Server configuration shared by native transports.
Enums
- Error
- Errors that can occur when sending or receiving WebSocket messages.
- Message
- WebSocket message representation used by websock.
Traits
- WebSocket
Connection - Cross-platform WebSocket connection contract.
Functions
Type Aliases
- Local
BoxFuture - Local boxed future used by transport traits.
- Result
- Result type for protocol and transport operations.